@@ -1,7 +1,7 @@
 package commands
 
 import (
-	"io/ioutil"
+	"io"
 
 	"github.com/jesseduffield/lazydocker/pkg/config"
 	"github.com/jesseduffield/lazydocker/pkg/i18n"
@@ -31,7 +31,7 @@ func NewDummyAppConfig() *config.AppConfig {
 // NewDummyLog creates a new dummy Log for testing
 func NewDummyLog() *logrus.Entry {
 	log := logrus.New()
-	log.Out = ioutil.Discard
+	log.Out = io.Discard
 	return log.WithField("test", "test")
 }
 
